=======
History
=======

.. v0.x (unreleased)
.. ---------------------

.. Breaking changes
.. ~~~~~~~~~~~~~~~~


.. New Features
.. ~~~~~~~~~~~~


.. Bug fixes
.. ~~~~~~~~~


.. Documentation
.. ~~~~~~~~~~~~~


.. Internal Changes
.. ~~~~~~~~~~~~~~~~

v0.1.1 (2022-05-12)
---------------------

This release brings lots of additions to the documentation and some other minor additions. We haven't gotten into the routine of adding changes to this file, so the notes below do not reflect all changes of this release.

Bug fixes
~~~~~~~~~
- Fix an indexing bug in the shear/strain parameterization (:pull:`80`).
  By `Henri Drake <https://github.com/hdrake>`_.


Documentation
~~~~~~~~~~~~~
- Lots of additions to the documentation (:pull:`80`).
  By `Henri Drake <https://github.com/hdrake>`_ and `Jesse Cusack <https://github.com/jessecusack>`_.


Internal Changes
~~~~~~~~~~~~~~~~
- Simplify overturn helper functions and unify variable names. (:pull:`93`).
  By `Jesse Cusack <https://github.com/jessecusack>`_.
- Add Thorpe scale function with unit test (:pull:`79`). 
  By `Henri Drake <https://github.com/hdrake>`_ and `Jesse Cusack <https://github.com/jessecusack>`_.

0.1.0 (2020-06-02)
------------------

* Initial release.
